# Python MCAP protobuf support

This package provides protobuf support for the Python MCAP file format reader.

## Installation

Install via [Pipenv](https://pipenv.pypa.io/en/latest/) by adding `mcap-protobuf-support` to your `Pipfile` or via the command line:

```bash
pipenv install mcap-protobuf-support
```

## Examples

Examples of use of this package can be found in the `/examples` directory. To run the examples first run
pipenv to install dependencies:

```bash
pip install pipenv
pipenv install
```

Then switch to the examples directory and run the setup script there:

```bash
cd examples
./setup.sh
```

You should now be able to run the examples:

```bash
pipenv run python point_cloud_example.py output.mcap
```

## Stay in touch

Join our [Discord community](https://foxglove.dev/chat) to ask questions, share feedback, and stay up to date on what our team is working on.
